@@ -1,4 +1,4 @@
-// $Id: BackupOptDlg.cpp 294381 2004-03-08 10:49:16Z waba $
+// $Id: BackupOptDlg.cpp 622348 2007-01-11 16:52:13Z mlaurent $
 //
 // KDat - a tar-based DAT archiver
 // Copyright (C) 1998-2000  Sean Vyain, svyain@mail.tds.net
@@ -16,13 +16,15 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
-#include <qlayout.h>
+#include <QLayout>
+//Added by qt3to4:
+#include <QVBoxLayout>
+#include <QHBoxLayout>
 #include <kpushbutton.h>
-#include <kstdguiitem.h>
-
-#include <kapplication.h>
+#include <KStandardGuiItem>
+#include <kguiitem.h>
 
 #include "BackupOptDlg.h"
 #include "BackupProfileWidget.h"
@@ -41,10 +43,10 @@ BackupOptDlg::BackupOptDlg( BackupProfile* backupProfile, QWidget* parent, const
     _profile = new BackupProfileWidget( this );
     _profile->setBackupProfile( backupProfile );
 
-    KPushButton* ok = new KPushButton( KStdGuiItem::ok(), this );
+    KPushButton* ok = new KPushButton( KStandardGuiItem::ok(), this );
     ok->setFixedSize( 80, ok->sizeHint().height() );
     connect( ok, SIGNAL( clicked() ), this, SLOT( accept() ) );
-    KPushButton* cancel = new KPushButton( KStdGuiItem::cancel(), this );
+    KPushButton* cancel = new KPushButton( KStandardGuiItem::cancel(), this );
     cancel->setFixedSize( 80, ok->sizeHint().height() );
     connect( cancel, SIGNAL( clicked() ), this, SLOT( reject() ) );
 
