@@ -19,8 +19,8 @@
 #include <stdlib.h>
 #include <unistd.h>
 
-#include <qdir.h>
-#include <qregexp.h>
+#include <QDir>
+#include <QRegExp>
 
 #include <kglobal.h>
 #include <kstandarddirs.h>
@@ -36,7 +36,7 @@ BackupProfileManager::BackupProfileManager()
     // Get a list of all available backup profiles.
     QStringList relList;
     (void) KGlobal::dirs()->findAllResources( "appdata", "*.bp", false, true, relList);
-    
+
     for(QStringList::Iterator it = relList.begin();
         it != relList.end();
         it++)
@@ -97,9 +97,9 @@ void BackupProfileManager::removeBackupProfile( BackupProfile* backupProfile )
     emit sigBackupProfileRemoved( backupProfile );
 
     // Remove the index file.
-    QString filename = locateLocal( "appdata", 
+    QString filename = KStandardDirs::locateLocal( "appdata",
                                     QString(backupProfile->getName()) + ".bp");
-    
+
     unlink( QFile::encodeName(filename) );
 
     _backupProfileNames.remove( backupProfile->getName() );
