@@ -14,12 +14,15 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #ifndef _Node_h_
 #define _Node_h_
 
 #include <qobject.h>
+//Added by qt3to4:
+#include <QPixmap>
+#include <Q3PtrList>
 
 #include "ktreeview.h"
 
@@ -400,7 +403,7 @@ public:
      * Get a list of all the selected ranges for the subtree rooted at this
      * node.
      */
-    virtual const QPtrList<Range>& getRanges() = 0;
+    virtual const Q3PtrList<Range>& getRanges() = 0;
 
     /**
      * Determine whether the node is an instance of the given node type.
@@ -442,7 +445,7 @@ public:
      * Get a list of all the selected ranges for the subtree rooted at this
      * node.
      */
-    virtual const QPtrList<Range>& getRanges();
+    virtual const Q3PtrList<Range>& getRanges();
 
     /**
      * Select/deselect this node and all of its children.
@@ -513,7 +516,7 @@ public:
      * Get a list of all the selected ranges for the subtree rooted at this
      * node.
      */
-    virtual const QPtrList<Range>& getRanges();
+    virtual const Q3PtrList<Range>& getRanges();
 
     /**
      * Select/deselect this node and all of its children.
@@ -593,7 +596,7 @@ public:
      * Get a list of all the selected ranges for the subtree rooted at this
      * node.
      */
-    virtual const QPtrList<Range>& getRanges();
+    virtual const Q3PtrList<Range>& getRanges();
 
     /**
      * Select/deselect this node and all of its children.
