@@ -21,29 +21,13 @@
 #include <kaboutdata.h>
 #include <klocale.h>
 #include <kuniqueapplication.h>
-#include <dcopclient.h>
-#include <kglobal.h>
 #include <kgenericfactory.h>
 
 //#include "knetworkconf.h"
 #include "knetworkconfmodule.h"
 #include "version.h"
+#include <kdemacros.h>
 	
-	
-static KCmdLineOptions options[] =
-{
-  { 0, 0, 0 }
-  // INSERT YOUR COMMANDLINE OPTIONS HERE
-};
-/*typedef KGenericFactory<KNetworkConfModule> KDEDFactory; 
-K_EXPORT_COMPONENT_FACTORY( knetworkconfmodule, KDEDFactory( "kcm_knetworkconfmodule" ) ); */
-
-extern "C"
-{
-  KDE_EXPORT KCModule *create_knetworkconfmodule(QWidget *parent, const char *name)
-  {
-    KGlobal::locale()->insertCatalogue("knetworkconf");
-    return new KNetworkConfModule(parent, name);
-  }
-}
-
+// 
+// KCmdLineOptions options;
+// 
